# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-01-12)

### Bug Fixes

- Add Codecov token to CI workflow ([#5](https://github.com/lan17/homesec/pull/5),
  [`6657cf2`](https://github.com/lan17/homesec/commit/6657cf2e94fe7bf8d0eaed39cfa98242f9766188))

- Correct Codecov badge URL case (HomeSec) ([#6](https://github.com/lan17/homesec/pull/6),
  [`74019fe`](https://github.com/lan17/homesec/commit/74019fe4b313d588a72e96ff86a7b647e69c8150))

### Features

- Add code coverage and improve documentation ([#4](https://github.com/lan17/homesec/pull/4),
  [`b1d9490`](https://github.com/lan17/homesec/commit/b1d949057db675ed20f2623f06cef1fd58c4dcc3))

### Testing

- Improve code coverage from 64% to 70% ([#7](https://github.com/lan17/homesec/pull/7),
  [`7b93468`](https://github.com/lan17/homesec/commit/7b934685e8389bb24c8cc8878cb43b5570f5371e))


## v1.0.2 (2026-01-11)

### Bug Fixes

- CI and release workflow improvements ([#3](https://github.com/lan17/homesec/pull/3),
  [`ab61e47`](https://github.com/lan17/homesec/commit/ab61e47c7c16c79e8472807c07e4974e31a13c29))


## v1.0.1 (2026-01-11)

### Bug Fixes

- Improve release workflow dry run and prevent major version jumps
  ([#2](https://github.com/lan17/HomeSec/pull/2),
  [`ba02512`](https://github.com/lan17/HomeSec/commit/ba025129de5caa984552807e4e0f376666db485e))


## v1.0.0 (2026-01-11)

- Initial Release
